@@ -1,7 +1,7 @@
 package Bencher::Scenario::TreeObject::Startup;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use Bencher::ScenarioUtil::TreeObject;
 
@@ -33,7 +33,7 @@ Bencher::Scenario::TreeObject::Startup - Benchmark startup of various tree class
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::TreeObject::Startup (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-04-14.
+This document describes version 0.05 of Bencher::Scenario::TreeObject::Startup (from Perl distribution Bencher-Scenarios-TreeObject), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -43,55 +43,35 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Tree::Object::Hash::ChildrenAsList> 0.07
-
-L<Tree::Object::Hash> 0.07
-
-L<Tree::ObjectXS::Array> 0.02
-
-L<Tree::Object::InsideOut> 0.07
-
-L<Tree::Object::Array::Glob> 0.07
+L<Tree::ObjectXS::Hash> 0.02
 
 L<Tree::Object::Array> 0.07
 
-L<Tree::ObjectXS::Hash> 0.02
+L<Tree::ObjectXS::Array> 0.02
+
+L<Tree::Object::Hash::ChildrenAsList> 0.07
+
+L<Tree::Object::Array::Glob> 0.07
+
+L<Tree::Object::Hash> 0.07
+
+L<Tree::Object::InsideOut> 0.07
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Tree::Object::Hash::ChildrenAsList (perl_code)
+=item * Tree::ObjectXS::Hash (perl_code)
 
-L<Tree::Object::Hash::ChildrenAsList>
-
-
-
-=item * Tree::Object::Hash (perl_code)
-
-L<Tree::Object::Hash>
-
-
-
-=item * Tree::ObjectXS::Array (perl_code)
-
-L<Tree::ObjectXS::Array>
-
-
-
-=item * Tree::Object::InsideOut (perl_code)
-
-L<Tree::Object::InsideOut>
-
-
-
-=item * Tree::Object::Array::Glob (perl_code)
-
-L<Tree::Object::Array::Glob>
+L<Tree::ObjectXS::Hash>
 
 
 
@@ -101,9 +81,33 @@ L<Tree::Object::Array>
 
 
 
-=item * Tree::ObjectXS::Hash (perl_code)
+=item * Tree::ObjectXS::Array (perl_code)
 
-L<Tree::ObjectXS::Hash>
+L<Tree::ObjectXS::Array>
+
+
+
+=item * Tree::Object::Hash::ChildrenAsList (perl_code)
+
+L<Tree::Object::Hash::ChildrenAsList>
+
+
+
+=item * Tree::Object::Array::Glob (perl_code)
+
+L<Tree::Object::Array::Glob>
+
+
+
+=item * Tree::Object::Hash (perl_code)
+
+L<Tree::Object::Hash>
+
+
+
+=item * Tree::Object::InsideOut (perl_code)
+
+L<Tree::Object::InsideOut>
 
 
 
@@ -111,26 +115,26 @@ L<Tree::ObjectXS::Hash>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m TreeObject::Startup >>):
 
- +------------------------------------+-----------+------------------------+------------+---------+---------+
- | participant                        | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +------------------------------------+-----------+------------------------+------------+---------+---------+
- | Tree::Object::InsideOut            | 41        | 11                     | 1          | 0.00015 | 20      |
- | Tree::ObjectXS::Array              | 39        | 9                      | 1          | 0.00012 | 20      |
- | Tree::ObjectXS::Hash               | 38        | 8                      | 1.1        | 7.3e-05 | 20      |
- | Tree::Object::Array                | 37        | 7                      | 1.1        | 7.6e-05 | 20      |
- | Tree::Object::Array::Glob          | 36        | 6                      | 1.1        | 9.8e-05 | 20      |
- | Tree::Object::Hash::ChildrenAsList | 36        | 6                      | 1.1        | 8.1e-05 | 20      |
- | Tree::Object::Hash                 | 36.3      | 6.3                    | 1.13       | 2.4e-05 | 20      |
- | perl -e1 (baseline)                | 30        | 0                      | 1.4        | 0.00015 | 20      |
- +------------------------------------+-----------+------------------------+------------+---------+---------+
+ #table1#
+ +------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant                        | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | Tree::Object::InsideOut            | 0.82                         | 4.2                | 16             |        48 |                     17 |       1    |   0.00021 |      20 |
+ | Tree::ObjectXS::Array              | 1.63                         | 5.15               | 18.8           |        43 |                     12 |       1.12 |   4e-05   |      20 |
+ | Tree::ObjectXS::Hash               | 0.84                         | 4.2                | 16             |        43 |                     12 |       1.1  | 9.8e-05   |      20 |
+ | Tree::Object::Array                | 0.84                         | 4.3                | 16             |        40 |                      9 |       1.2  | 6.3e-05   |      21 |
+ | Tree::Object::Array::Glob          | 1.6                          | 5                  | 19             |        40 |                      9 |       1.2  | 7.2e-05   |      22 |
+ | Tree::Object::Hash                 | 2.4                          | 5.8                | 20             |        40 |                      9 |       1.2  |   0.00013 |      20 |
+ | Tree::Object::Hash::ChildrenAsList | 0.84                         | 4.1                | 16             |        39 |                      8 |       1.2  | 4.1e-05   |      20 |
+ | perl -e1 (baseline)                | 2                            | 5.4                | 21             |        31 |                      0 |       1.6  | 3.1e-05   |      20 |
+ +------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -156,7 +160,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
