@@ -1,7 +1,7 @@
 package Bencher::Scenario::TreeObject::descendants;
 
-our $DATE = '2016-04-14'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,7 +41,7 @@ Bencher::Scenario::TreeObject::descendants - Benchmark descendants()
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::TreeObject::descendants (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-04-14.
+This document describes version 0.05 of Bencher::Scenario::TreeObject::descendants (from Perl distribution Bencher-Scenarios-TreeObject), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -55,6 +55,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -163,40 +167,41 @@ A tree with height=6 and 5 children per non-leaf nodes, nodes=1 + 5 + 25 + 125 +
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with C<< bencher -m TreeObject::descendants --include-datasets 'small1 (31 nodes)' >>:
 
+ #table1#
  +------------------------------------+-----------+-----------+------------+---------+---------+
- | participant                        | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ | participant                        | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +------------------------------------+-----------+-----------+------------+---------+---------+
- | Tree::Object::Array::Glob          | 2.65e+04  | 37.8      | 1          | 1.3e-08 | 21      |
- | Tree::Object::InsideOut            | 2.72e+04  | 36.7      | 1.03       | 1.3e-08 | 22      |
- | Tree::Object::Hash                 | 3.03e+04  | 33        | 1.14       | 1.1e-08 | 30      |
- | Tree::Object::Array                | 32845.9   | 30.4452   | 1.24128    | 0       | 20      |
- | Tree::Object::Hash::ChildrenAsList | 3.3e+04   | 30        | 1.2        | 3.9e-08 | 21      |
- | Tree::ObjectXS::Hash               | 3.64e+04  | 27.5      | 1.38       | 1.3e-08 | 20      |
- | Tree::ObjectXS::Array              | 3.7e+04   | 27        | 1.4        | 5.2e-08 | 21      |
+ | Tree::Object::Array::Glob          |   20000   |   50      |    1       | 5.3e-08 |      20 |
+ | Tree::Object::InsideOut            |   22284.3 |   44.8746 |    1.11045 | 1.1e-11 |      20 |
+ | Tree::Object::Hash                 |   23100   |   43.3    |    1.15    | 1.3e-08 |      20 |
+ | Tree::Object::Array                |   24900   |   40.1    |    1.24    |   4e-08 |      20 |
+ | Tree::Object::Hash::ChildrenAsList |   28000   |   36      |    1.4     | 5.3e-08 |      20 |
+ | Tree::ObjectXS::Hash               |   30239   |   33.069  |    1.5069  | 9.1e-11 |      21 |
+ | Tree::ObjectXS::Array              |   30800   |   32.5    |    1.53    | 1.2e-08 |      26 |
  +------------------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark with C<< bencher -m TreeObject::descendants --include-datasets 'medium1 (19531 nodes)' >>:
 
- +------------------------------------+-----------+-----------+------------+---------+---------+
- | participant                        | rate (/s) | time (ms) | vs_slowest | errors  | samples |
- +------------------------------------+-----------+-----------+------------+---------+---------+
- | Tree::Object::InsideOut            | 35        | 28.5      | 1          | 1.3e-05 | 20      |
- | Tree::Object::Array::Glob          | 43.9      | 22.8      | 1.25       | 1.2e-05 | 20      |
- | Tree::Object::Hash                 | 47        | 21.3      | 1.34       | 1.7e-05 | 20      |
- | Tree::Object::Hash::ChildrenAsList | 51.1      | 19.6      | 1.46       | 6.8e-06 | 21      |
- | Tree::Object::Array                | 55.4      | 18.1      | 1.58       | 1.2e-05 | 21      |
- | Tree::ObjectXS::Hash               | 57.3      | 17.5      | 1.63       | 5.8e-06 | 22      |
- | Tree::ObjectXS::Array              | 61.3      | 16.3      | 1.75       | 7.4e-06 | 21      |
- +------------------------------------+-----------+-----------+------------+---------+---------+
+ #table2#
+ +------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                        | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +------------------------------------+-----------+-----------+------------+-----------+---------+
+ | Tree::Object::InsideOut            |        30 |        33 |        1   | 6.3e-05   |      20 |
+ | Tree::Object::Array::Glob          |        36 |        28 |        1.2 | 5.3e-05   |      20 |
+ | Tree::Object::Hash                 |        37 |        27 |        1.2 |   0.00012 |      20 |
+ | Tree::Object::Hash::ChildrenAsList |        41 |        24 |        1.4 |   6e-05   |      20 |
+ | Tree::Object::Array                |        42 |        24 |        1.4 | 9.8e-05   |      20 |
+ | Tree::ObjectXS::Hash               |        47 |        21 |        1.5 | 5.7e-05   |      20 |
+ | Tree::ObjectXS::Array              |        48 |        21 |        1.6 |   0.00017 |      20 |
+ +------------------------------------+-----------+-----------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -220,7 +225,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
